//This file is part of AcetoneISO. Copyright 2006,2007,2008,2009 Fabrizio Di Marco and Marco Di Antonio  (acetoneiso@gmail.com)
//
//    AcetoneISO is free software: you can redistribute it and/or modify
//    it under the terms of the GNU General Public License as published by
//    the Free Software Foundation, either version 3 of the License, or
//    (at your option) any later version.
//
//    AcetoneISO is distributed in the hope that it will be useful,
//    but WITHOUT ANY WARRANTY; without even the implied warranty of
//    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//    GNU General Public License for more details.
//
//    You should have received a copy of the GNU General Public License
//    along with AcetoneISO.  If not, see <http://www.gnu.org/licenses/>.

//Questa libreria permette di leggere un rigo n da un file.
//per richiamare questa funzione per un qfile nomefile e leggere
//il rigo n basta fare: leggiRigo( n, &nomefile) e ci verrà
//restituita una qstring contenente il rigo n-esimo di nomefile.

QByteArray acetoneiso::leggiRigo( int numeroRigo, QFile *filee )
{
QByteArray line = "";    
for(int i = 0; i < numeroRigo; i++)
line = filee->readLine();
return line ;
}
